<?php
/**
 * Helper functions for the Newspaper AI Plugin
 */

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Log debug messages to WordPress debug log
 *
 * @param mixed $message The message to log
 * @param string $component The component generating the log
 * @return void
 */
function newspaper_ai_debug_log($message, $component = 'General') {
    if (!defined('WP_DEBUG') || !WP_DEBUG) {
        return;
    }

    if (is_array($message) || is_object($message)) {
        $message = print_r($message, true);
    }

    $timestamp = current_time('Y-m-d H:i:s');
    $formatted_message = sprintf('[%s] [%s] %s', $timestamp, $component, $message);

    // Use WordPress native error logging
    error_log($formatted_message);
}

/**
 * Check if user has premium access
 *
 * @return boolean
 */
function newspaper_ai_is_premium() {
    return false; // Default to free version for now
}

/**
 * Get the API key from options
 *
 * @return string|false
 */
function newspaper_ai_get_api_key() {
    return get_option('newspaper_ai_api_key', false);
}

/**
 * Get premium upgrade URL
 *
 * @return string
 */
function newspaper_ai_get_upgrade_url() {
    return '#'; // Placeholder URL
}

/**
 * Validate if a feature is accessible
 *
 * @param string $feature_name
 * @return boolean
 */
function newspaper_ai_can_access_feature($feature_name) {
    if ($feature_name === 'weather') {
        return true;
    }
    return newspaper_ai_is_premium();
}

/**
 * Format error message for display
 *
 * @param string $message
 * @return string
 */
function newspaper_ai_format_error($message) {
    return sprintf(
        '<div class="notice notice-error"><p>%s</p></div>',
        esc_html($message)
    );
}

/**
 * Format success message for display
 *
 * @param string $message
 * @return string
 */
function newspaper_ai_format_success($message) {
    return sprintf(
        '<div class="notice notice-success"><p>%s</p></div>',
        esc_html($message)
    );
}

// Enqueue Leaflet scripts and styles
function newspaper_ai_enqueue_leaflet() {
    if (is_single()) {  // Only on single post pages
        wp_enqueue_style('leaflet', 'https://unpkg.com/leaflet@1.9.4/dist/leaflet.css', array(), '1.9.4');
        wp_enqueue_script('leaflet', 'https://unpkg.com/leaflet@1.9.4/dist/leaflet.js', array('jquery'), '1.9.4', true);
    }
}
add_action('wp_enqueue_scripts', 'newspaper_ai_enqueue_leaflet');

// Debug script loading
function newspaper_ai_debug_scripts() {
    if (is_single()) {  // Only on single post pages
        ?>
        <script>
            console.log('Script loading debug:');
            console.log('jQuery version:', typeof jQuery !== 'undefined' ? jQuery.fn.jquery : 'not loaded');
            console.log('Leaflet version:', typeof L !== 'undefined' ? L.version : 'not loaded');
        </script>
        <?php
    }
}
add_action('wp_footer', 'newspaper_ai_debug_scripts', 99);
