<?php
/**
 * Debug script for weather image URLs
 */

// Load WordPress
$wp_load_path = dirname(dirname(dirname(dirname(dirname(dirname(__FILE__)))))) . '/wp-load.php';
require_once($wp_load_path);

// Include the necessary classes
require_once('class-weather-images-installer.php');
require_once('class-weather-images.php');

// Create instances
$installer = NewspaperAI_Weather_Images_Installer::get_instance();
$weather_images = new NewspaperAI_Weather_Images();

// Test image types
$types = ['sunny', 'cloudy', 'partly_cloudy', 'storm', 'rain', 'snow', 'fog'];

// Output header
header('Content-Type: text/html');
echo '<!DOCTYPE html>
<html>
<head>
    <title>Weather Image URL Debug</title>
    <style>
        body { font-family: Arial, sans-serif; margin: 20px; }
        .test-section { margin-bottom: 30px; }
        .image-grid { display: flex; flex-wrap: wrap; gap: 15px; margin-top: 15px; }
        .image-item { border: 1px solid #ddd; padding: 10px; text-align: center; }
        img { max-width: 100px; max-height: 100px; display: block; margin: 0 auto; }
        .success { color: green; }
        .error { color: red; }
        pre { background: #f5f5f5; padding: 10px; overflow: auto; }
    </style>
</head>
<body>
    <h1>Weather Image URL Debug</h1>';

// Get the installer properties using reflection
$installer_reflection = new ReflectionClass('NewspaperAI_Weather_Images_Installer');
$images_dir_property = $installer_reflection->getProperty('images_dir');
$images_url_property = $installer_reflection->getProperty('images_url');
$images_dir_property->setAccessible(true);
$images_url_property->setAccessible(true);

$images_dir = $images_dir_property->getValue($installer);
$images_url = $images_url_property->getValue($installer);

// Display path information
echo '<div class="test-section">
    <h2>Path Information</h2>
    <pre>
Images Directory: ' . $images_dir . '
Images URL: ' . $images_url . '
Site URL: ' . site_url() . '
Home URL: ' . home_url() . '
WP Content URL: ' . content_url() . '
Plugins URL: ' . plugins_url() . '
    </pre>
</div>';

// Test direct image URLs
echo '<div class="test-section">
    <h2>Direct Image URLs</h2>
    <div class="image-grid">';

foreach ($types as $type) {
    for ($variation = 1; $variation <= 3; $variation++) {
        $image_file = $type . '-' . $variation . '.jpg';
        $image_path = $images_dir . $image_file;
        $image_url = $images_url . $image_file;
        $exists = file_exists($image_path);
        
        echo '<div class="image-item">
            <p><strong>' . $type . '-' . $variation . '</strong></p>
            <img src="' . $image_url . '" alt="' . $type . '-' . $variation . '">
            <p class="' . ($exists ? 'success' : 'error') . '">File exists: ' . ($exists ? 'Yes' : 'No') . '</p>
            <p>URL: ' . $image_url . '</p>
        </div>';
    }
}

echo '</div></div>';

// Test using the Weather_Images class
echo '<div class="test-section">
    <h2>Using Weather_Images Class</h2>
    <div class="image-grid">';

foreach ($types as $type) {
    for ($variation = 1; $variation <= 3; $variation++) {
        $image_url = $weather_images->get_weather_image_url($type, $variation);
        
        echo '<div class="image-item">
            <p><strong>' . $type . '-' . $variation . '</strong></p>
            <img src="' . $image_url . '" alt="' . $type . '-' . $variation . '">
            <p>URL: ' . $image_url . '</p>
        </div>';
    }
}

echo '</div></div>';

// Test alternative URL formats
echo '<div class="test-section">
    <h2>Alternative URL Formats</h2>
    <div class="image-grid">';

// Test with a couple of different URL formats
$alt_urls = [
    'Direct plugin URL' => plugins_url('assets/images/weather/partly_cloudy-1.jpg', dirname(dirname(__FILE__))),
    'Content URL' => content_url('plugins/Publisher_Plugin/assets/images/weather/partly_cloudy-1.jpg'),
    'Site URL' => site_url('wp-content/plugins/Publisher_Plugin/assets/images/weather/partly_cloudy-1.jpg'),
    'Home URL' => home_url('wp-content/plugins/Publisher_Plugin/assets/images/weather/partly_cloudy-1.jpg')
];

foreach ($alt_urls as $label => $url) {
    echo '<div class="image-item">
        <p><strong>' . $label . '</strong></p>
        <img src="' . $url . '" alt="' . $label . '">
        <p>URL: ' . $url . '</p>
    </div>';
}

echo '</div></div>';

echo '</body></html>';
