<?php
/**
 * Test Weather Images Installer
 * 
 * This script tests the weather images installer by forcing a download of all default images
 */

// Bootstrap WordPress
define('WP_USE_THEMES', false);
require_once('../../../../wp-load.php');

// Verify we're in WordPress
if (!function_exists('add_action')) {
    die('This script must be run within WordPress');
}

// Security check - only run if admin is logged in
if (!current_user_can('manage_options')) {
    wp_die('You must be an administrator to run this script');
}

// Load the installer
require_once dirname(__FILE__) . '/class-weather-images-installer.php';
$installer = NewspaperAI_Weather_Images_Installer::get_instance();

// Clear any existing images
$images_dir = plugin_dir_path(dirname(dirname(__FILE__))) . 'assets/images/weather/';
if (file_exists($images_dir)) {
    $files = glob($images_dir . '*.jpg');
    foreach ($files as $file) {
        unlink($file);
    }
}

// Force download of all default images
$installer->download_default_images();

// Clear any cached images
delete_option('weather_write_images');
delete_option('newspaper_ai_weather_images');

// Output HTML
echo '<div style="font-family: Arial, sans-serif; max-width: 800px; margin: 0 auto; padding: 20px;">';
echo '<h1>Weather Images Installer Test</h1>';

// Check if images were downloaded
$images_dir = plugin_dir_path(dirname(dirname(__FILE__))) . 'assets/images/weather/';
$files = glob($images_dir . '*.jpg');
$count = count($files);

if ($count > 0) {
    echo '<p style="color: green;">✅ Successfully downloaded ' . $count . ' default weather images.</p>';
} else {
    echo '<p style="color: red;">❌ Failed to download default weather images.</p>';
}

// Display some of the downloaded images
echo '<h2>Sample Downloaded Images</h2>';
echo '<div style="display: grid; grid-template-columns: repeat(auto-fill, minmax(200px, 1fr)); gap: 20px;">';

// Define weather types to display
$weather_types = ['sunny', 'partly_cloudy', 'overcast', 'rain_light', 'thunderstorm'];

// Get the URL to the images directory
$images_url = plugins_url('/Publisher_Plugin/assets/images/weather/');

foreach ($weather_types as $type) {
    for ($variation = 1; $variation <= 1; $variation++) {
        $image_path = $images_dir . $type . '-' . $variation . '.jpg';
        $image_url = $images_url . $type . '-' . $variation . '.jpg';
        
        echo '<div style="border: 1px solid #ddd; padding: 10px; border-radius: 4px;">';
        echo '<p><strong>' . ucwords(str_replace('_', ' ', $type)) . ' (Variation ' . $variation . ')</strong></p>';
        
        if (file_exists($image_path)) {
            echo '<img src="' . esc_url($image_url) . '" style="max-width: 100%; height: auto;" alt="' . esc_attr($type . ' ' . $variation) . '">';
            echo '<p style="font-size: 12px; word-break: break-all;">Size: ' . filesize($image_path) . ' bytes</p>';
        } else {
            echo '<p style="color: red;">Image not found</p>';
        }
        
        echo '</div>';
    }
}

echo '</div>';

// Show next steps
echo '<h2>Next Steps</h2>';
echo '<p>The weather images have been downloaded from S3. You can now:</p>';
echo '<ol>';
echo '<li>Go to the <a href="' . admin_url('admin.php?page=newspaper-ai-weather&tab=images') . '">Weather Images tab</a> to see the default images.</li>';
echo '<li>Generate a weather report to test that everything is working properly.</li>';
echo '</ol>';

echo '<p><a href="' . admin_url('admin.php?page=newspaper-ai-weather&tab=images') . '" style="display: inline-block; background: #2271b1; color: white; padding: 10px 15px; text-decoration: none; border-radius: 3px;">Go to Weather Images Tab</a></p>';

echo '</div>';
