jQuery(document).ready(function($) {
    // Find all weather map containers
    var $maps = $('.weather-map');
    
    $maps.each(function() {
        var $container = $(this);
        var mapId = $container.attr('id');
        var mapData = window['weatherMap_' + mapId];
        
        if (!mapData) return;

        // Function to initialize map
        var initMap = function() {
            if (typeof L === 'undefined') return false;

            var $mapContainer = $('#' + mapId);
            if (!$mapContainer.length) return false;

            try {
                var map = L.map(mapId, {
                    center: [mapData.lat, mapData.lng],
                    zoom: 8,
                    zoomControl: true,
                    scrollWheelZoom: false
                });

                L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
                    attribution: 'OpenStreetMap contributors',
                    maxZoom: 18
                }).addTo(map);

                L.marker([mapData.lat, mapData.lng])
                    .addTo(map)
                    .bindPopup(mapData.city + ', ' + mapData.state)
                    .openPopup();

                if (mapData.radarUrl) {
                    L.tileLayer.wms(mapData.radarUrl, {
                        layers: 'conus_bref_qcd',
                        format: 'image/png',
                        transparent: true,
                        opacity: 0.6,
                        attribution: 'NOAA Weather Radar'
                    }).addTo(map);
                }

                // Force map to update its size
                setTimeout(function() {
                    map.invalidateSize();
                }, 100);

                return true;
            } catch (error) {
                return false;
            }
        };

        // Try to initialize map multiple times
        var attempts = 0;
        var maxAttempts = 10;  
        var interval = setInterval(function() {
            if (initMap() || attempts >= maxAttempts) {
                clearInterval(interval);
            }
            attempts++;
        }, 1000);
    });
});
