<?php
/**
 * Class to handle weather-related assets
 */
class NewspaperAI_Weather_Assets {
    private static $instance = null;

    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function __construct() {
        add_action('wp_enqueue_scripts', array($this, 'enqueue_styles'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_styles'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_map_scripts'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_map_scripts'));
        add_action('wp_head', array($this, 'add_map_container_styles'));
    }

    /**
     * Register all required assets
     */
    public function register_assets() {
        // Register our weather assets
        wp_register_script(
            'newspaper-ai-weather',
            plugins_url('/js/weather.js', __FILE__),
            array('jquery', 'leaflet'),
            filemtime(plugin_dir_path(__FILE__) . 'js/weather.js'),
            true
        );
    }

    

    public function enqueue_weather_styles() {
        wp_enqueue_style(
            'newspaper-ai-weather-report',
            NEWSPAPER_AI_URL . 'modules/weather/css/weather-report.css',
            array(),
            NEWSPAPER_AI_VERSION
        );

        // Add inline styles for weather report
        $custom_css = "
            .weather-report {
                max-width: 800px;
                margin: 0 auto;
                font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
                padding: 20px;
                background: #fff;
                box-shadow: 0 2px 4px rgba(0,0,0,0.1);
                border-radius: 8px;
            }

            .weather-report h1 {
                color: #2c3e50;
                font-size: 2em;
                margin-bottom: 1em;
                text-align: center;
            }

            .current-conditions {
                background: #f8f9fa;
                padding: 20px;
                border-radius: 8px;
                margin-bottom: 20px;
            }

            .weather-hourly-chart-container {
                background: #f8f9fa;
                padding: 20px;
                border-radius: 8px;
                margin: 20px 0;
                height: 400px;
            }

            .weather-hourly-chart-container canvas {
                width: 100% !important;
                height: 100% !important;
            }

            .main-forecast {
                font-size: 1.2em;
                line-height: 1.5;
                color: #34495e;
                margin-bottom: 15px;
            }

            .temperature-range {
                font-size: 1.4em;
                font-weight: bold;
                color: #2c3e50;
                margin: 10px 0;
            }

            .precipitation {
                color: #3498db;
                font-size: 1.1em;
                margin: 10px 0;
            }

            .recommendations {
                background: #fff;
                padding: 15px;
                border-left: 4px solid #3498db;
                margin: 15px 0;
            }

            .recommendations h3 {
                color: #2c3e50;
                margin-bottom: 10px;
            }

            .recommendations ul {
                list-style-type: none;
                padding: 0;
                margin: 0;
            }

            .recommendations li {
                margin: 8px 0;
                padding-left: 20px;
                position: relative;
            }

            .recommendations li:before {
                content: '•';
                color: #3498db;
                position: absolute;
                left: 0;
            }

            .weather-map {
                border: 1px solid #e0e0e0;
                border-radius: 8px;
                overflow: hidden;
            }

            .five-day-forecast {
                margin-top: 30px;
            }

            .five-day-forecast h2 {
                color: #2c3e50;
                margin-bottom: 20px;
                text-align: center;
            }

            .forecast-grid {
                display: grid;
                grid-template-columns: repeat(auto-fit, minmax(150px, 1fr));
                gap: 20px;
                margin-top: 20px;
            }

            .forecast-day {
                background: #f8f9fa;
                padding: 15px;
                border-radius: 8px;
                text-align: center;
                transition: transform 0.2s;
            }

            .forecast-day:hover {
                transform: translateY(-2px);
                box-shadow: 0 4px 8px rgba(0,0,0,0.1);
            }

            .forecast-day h3 {
                color: #2c3e50;
                margin: 0 0 10px 0;
                font-size: 1.1em;
            }

            .weather-icon {
                width: 50px;
                height: 50px;
                margin: 10px auto;
            }

            .temp-range {
                font-weight: bold;
                color: #34495e;
                margin: 10px 0;
            }

            .conditions {
                color: #7f8c8d;
                font-size: 0.9em;
            }

            @media (max-width: 600px) {
                .forecast-grid {
                    grid-template-columns: repeat(auto-fit, minmax(120px, 1fr));
                    gap: 10px;
                }

                .weather-report {
                    padding: 10px;
                }

                .weather-report h1 {
                    font-size: 1.5em;
                }
            }
        ";

        wp_add_inline_style('newspaper-ai-weather-report', $custom_css);
    }

    public function enqueue_styles() {
        wp_enqueue_style(
            'newspaper-ai-weather',
            NEWSPAPER_AI_URL . 'modules/weather/css/weather.css',
            array(),
            NEWSPAPER_AI_VERSION
        );

        // Enqueue Chart.js from CDN
        wp_enqueue_script(
            'chartjs',
            'https://cdn.jsdelivr.net/npm/chart.js',
            array(),
            '4.4.1',
            true
        );

        // Enqueue our hourly chart initialization script
        wp_enqueue_script(
            'newspaper-ai-weather-hourly',
            NEWSPAPER_AI_URL . 'modules/weather/js/weather-hourly.js',
            array('jquery', 'chartjs'),
            NEWSPAPER_AI_VERSION,
            true
        );

        // Add inline styles for weather report
        $custom_css = "
            .weather-report {
                max-width: 800px;
                margin: 2rem auto;
                font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
                background: #fff;
                padding: 40px;
            }

            .weather-content {
                margin: 0 auto;
            }

            .weather-narrative {
                margin-bottom: 40px;
                line-height: 1.6;
                color: #333;
                font-size: 16px;
            }

            .weather-details {
                width: 100%;
                max-width: 500px;
                margin: 40px auto;
                border-collapse: collapse;
            }

            .weather-details td {
                padding: 12px;
                border-bottom: 1px solid #eee;
                font-size: 16px;
            }

            .weather-details td:first-child {
                color: #666;
                width: 120px;
            }

            .weather-details td:last-child {
                color: #1a1a1a;
                font-weight: 500;
            }

            .weather-hourly-chart-container {
                max-width: 800px;
                margin: 40px auto;
            }

            .weather-hourly-chart-container h3 {
                text-align: center;
                margin-bottom: 20px;
                color: #1a1a1a;
                font-size: 24px;
                font-weight: 500;
            }

            canvas {
                width: 100% !important;
                height: 300px !important;
            }

            .current-conditions {
                margin-bottom: 40px;
            }

            .current-temp {
                font-size: 72px;
                line-height: 1;
                margin-bottom: 15px;
                color: #1a1a1a;
            }

            .temp-details {
                margin-top: 20px;
            }

            .high-low {
                font-size: 18px;
                color: #333;
                margin-top: 10px;
            }

            .weather-details {
                width: 100%;
                max-width: 500px;
                margin: 0 auto 40px;
                border-collapse: collapse;
                font-size: 16px;
            }

            .weather-details td {
                padding: 12px;
                border-bottom: 1px solid #eee;
            }

            .detail-label {
                color: #666;
                width: 120px;
            }

            .detail-value {
                color: #1a1a1a;
                font-weight: 500;
            }

            .weather-narrative {
                margin: 30px 0;
                line-height: 1.6;
                color: #333;
            }

            .weather-hourly-chart-container {
                max-width: 800px;
                margin: 40px auto;
                padding: 20px 0;
            }

            .weather-hourly-chart-container h3 {
                text-align: center;
                margin-bottom: 20px;
                color: #1a1a1a;
                font-size: 24px;
            }

            canvas {
                width: 100% !important;
                height: 300px !important;
            }
                background: linear-gradient(135deg, #e3f2fd 0%, #bbdefb 100%);
                padding: 2rem;
                border-radius: 12px;
                margin-bottom: 2rem;
                box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            }

            .map-container {
                background: white;
                padding: 1.5rem;
                border-radius: 12px;
                margin: 2rem 0;
                box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            }

            .map-container h2 {
                color: #1a237e;
                margin: 0 0 1rem 0;
                font-size: 1.5em;
                font-weight: 600;
            }

            .weather-map {
                height: 400px;
                border-radius: 8px;
                overflow: hidden;
                border: 1px solid #e0e0e0;
            }

            .extended-forecast {
                background: white;
                padding: 1.5rem;
                border-radius: 12px;
                margin-top: 2rem;
                box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            }

            .extended-forecast h2 {
                color: #1a237e;
                margin: 0 0 1.5rem 0;
                text-align: center;
                font-size: 1.8em;
                font-weight: 700;
            }

            .forecast-grid {
                display: grid;
                grid-template-columns: repeat(5, 1fr);
                gap: 1.25rem;
            }

            .forecast-card {
                background: white;
                border-radius: 12px;
                overflow: hidden;
                box-shadow: 0 4px 6px rgba(0,0,0,0.1);
                transition: transform 0.3s ease, box-shadow 0.3s ease;
            }

            .forecast-card:hover {
                transform: translateY(-5px);
                box-shadow: 0 8px 12px rgba(0,0,0,0.15);
            }

            .forecast-card-header {
                background: linear-gradient(135deg, #1976d2 0%, #1565c0 100%);
                color: white;
                padding: 0.75rem;
                text-align: center;
            }

            .forecast-card-header h3 {
                margin: 0;
                font-size: 1.1em;
                font-weight: 600;
            }

            .forecast-card-body {
                padding: 1rem;
                text-align: center;
            }

            .weather-icon {
                width: 60px;
                height: 60px;
                margin: 0.5rem auto;
                display: block;
            }

            .temp-range {
                margin: 1rem 0;
                font-size: 1.2em;
                color: #1a237e;
            }

            .temp-range .high {
                font-weight: 700;
                color: #e65100;
            }

            .temp-range .low {
                font-weight: 700;
                color: #0277bd;
            }

            .temp-range .temp-divider {
                margin: 0 5px;
                color: #90a4ae;
            }

            .conditions {
                color: #37474f;
                font-size: 0.95em;
                margin: 0.75rem 0;
                min-height: 2.8em;
                line-height: 1.4;
            }

            .wind, .precip {
                font-size: 0.9em;
                color: #546e7a;
                margin: 0.5rem 0;
            }

            .wind-label, .precip-label {
                color: #1976d2;
                font-weight: 600;
                margin-right: 5px;
            }

            @media (max-width: 900px) {
                .weather-report {
                    margin: 1rem;
                    border-radius: 8px;
                }

                .weather-content {
                    padding: 1rem;
                }

                .forecast-grid {
                    grid-template-columns: repeat(auto-fit, minmax(160px, 1fr));
                    gap: 1rem;
                }

                .weather-map {
                    height: 300px;
                }
            }

            @media (max-width: 480px) {
                .weather-header h1 {
                    font-size: 1.8em;
                }

                .weather-content {
                    padding: 0.75rem;
                }

                .current-conditions,
                .map-container,
                .extended-forecast {
                    padding: 1rem;
                }

                .weather-map {
                    height: 250px;
                }
            }

            /* Fix for Leaflet map controls */
            .leaflet-control-container .leaflet-control {
                clear: both;
                pointer-events: auto;
            }

            .leaflet-control-container .leaflet-control-zoom a {
                color: #333;
            }
        ";

        wp_add_inline_style('newspaper-ai-weather', $custom_css);
    }

    public function enqueue_map_scripts() {
        // Enqueue Leaflet CSS and JS
        wp_enqueue_style(
            'leaflet',
            'https://unpkg.com/leaflet@1.9.4/dist/leaflet.css',
            array(),
            '1.9.4'
        );

        wp_enqueue_script(
            'leaflet',
            'https://unpkg.com/leaflet@1.9.4/dist/leaflet.js',
            array('jquery'),
            '1.9.4',
            true
        );
    }

    /**
     * Enqueue required assets and localize data
     */
    public function enqueue_weather_assets($lat, $lng, $city, $state, $radar_url) {
        // Enqueue required styles and scripts
        wp_enqueue_script('newspaper-ai-weather');

        // Localize the script with our data
        wp_localize_script('newspaper-ai-weather', 'weatherData', array(
            'lat' => floatval($lat),
            'lng' => floatval($lng),
            'city' => esc_js($city),
            'state' => esc_js($state),
            'radarUrl' => esc_url($radar_url)
        ));
    }
}
