jQuery(document).ready(function($) {
    console.log('Weather admin script loaded');
    
    // Check if premium
    var isPremium = (typeof weatherAjax !== 'undefined' && weatherAjax.isPremium === '1');
    console.log('Premium status:', isPremium);
    
    // Disable buttons for non-premium users
    function setupPremiumRestrictions() {
        $('.weather-image-upload').each(function() {
            var $button = $(this);
            var variation = parseInt($button.data('variation'));
            var $previewContainer = $button.siblings('.weather-image-preview');
            
            if (!isPremium && variation > 1) {
                // Disable button
                $button.prop('disabled', true).addClass('disabled');
                
                // Apply blur effect to the image
                $previewContainer.find('img').css({
                    'filter': 'blur(5px)',
                    '-webkit-filter': 'blur(5px)',
                    'transition': 'filter 0.3s ease'
                });
                
                // Add a clickable premium badge in the center if it doesn't exist
                if (!$previewContainer.find('.premium-badge').length) {
                    $previewContainer.append('\
                        <a href="https://buy.stripe.com/14kg2G9Gefrf4aQ001" target="_blank" class="premium-badge" style="position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); background-color: #228be6; color: white; padding: 5px 10px; border-radius: 4px; font-size: 14px; font-weight: bold; z-index: 10; text-decoration: none; cursor: pointer; box-shadow: 0 2px 4px rgba(0,0,0,0.2);">Premium Only</a>\
                    ');
                }
            }
        });
    }
    
    // Apply premium restrictions on page load
    setupPremiumRestrictions();
    
    // Handle image upload button clicks
    $('.weather-image-upload').on('click', function(e) {
        e.preventDefault();
        console.log('Weather image upload button clicked');

        var button = $(this);
        var type = button.data('type');
        var variation = parseInt(button.data('variation'));
        var previewContainer = button.siblings('.weather-image-preview');
        
        // Block premium variations for non-premium users
        if (!isPremium && variation > 1) {
            alert('Premium account required to use additional image variations. Click the "Premium Only" button to upgrade and unlock all weather images!');
            return;
        }
        
        console.log('Button data:', {
            type: type,
            variation: variation
        });

        // Create new media frame - check if wp is available directly or through window
        var wpMedia = (typeof wp !== 'undefined') ? wp : (window.wp || null);
        
        if (!wpMedia || !wpMedia.media) {
            console.error('WordPress Media Library not available');
            alert('WordPress Media Library not available. Please try refreshing the page.');
            return;
        }
        
        var frame = wpMedia.media({
            title: 'Select Weather Image',
            button: {
                text: 'Use this image'
            },
            multiple: false,
            library: {
                type: 'image'
            }
        });

        // When image is selected
        frame.on('select', function() {
            // Close the frame immediately
            frame.close();
            
            var attachment = frame.state().get('selection').first().toJSON();
            
            // Update preview
            previewContainer.html('<img src="' + attachment.url + '" alt="Weather image preview" />');
            button.text('Change Image');

            // Log what we're sending
            console.log('Sending AJAX request with:', {
                action: 'save_weather_image',
                nonce: weatherAjax.nonce,
                type: type,
                variation: variation,
                image_id: attachment.id,
                image_url: attachment.url
            });
            
            // Save image data via AJAX
            $.ajax({
                url: weatherAjax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'save_weather_image',
                    nonce: weatherAjax.nonce, // Use the localized nonce
                    type: type,
                    variation: variation,
                    image_id: attachment.id,
                    image_url: attachment.url
                },
                success: function(response) {
                    console.log('AJAX response:', response);
                    if (response.success) {
                        alert('Weather image updated successfully!');
                    } else {
                        console.error('Error response:', response);
                        alert(response.data || 'Failed to save image. Please try again.');
                    }
                },
                error: function(xhr, status, error) {
                    console.error('AJAX error:', status, error);
                    alert('Failed to save image. Please try again. Error: ' + error);
                }
            });
        });

        // Open frame
        frame.open();
    });
});
