jQuery(document).ready(function($) {
    // Check if premium
    var isPremium = newspaperAIWeather.isPremium === '1';
    
    // Store frames for each button
    var frames = {};
    
    // Set up initial locked states for non-premium users
    $('.weather-image-upload').each(function() {
        var $button = $(this);
        var variation = parseInt($button.data('variation'));
        var $previewContainer = $button.siblings('.weather-image-preview');
        
        if (!isPremium && variation > 1) {
            // Add blur effect and premium badge to variations 2 and 3 for non-premium users
            setupLockedState($previewContainer);
            $button.prop('disabled', true).addClass('disabled');
        } else if ($previewContainer.is(':empty')) {
            $previewContainer.html('<div class="weather-image-placeholder"><span class="dashicons dashicons-format-image"></span></div>');
        }
    });

    // Ensure locked states are applied after any dynamic content changes
    setTimeout(function() {
        $('.weather-image-upload').each(function() {
            var $button = $(this);
            var variation = parseInt($button.data('variation'));
            if (!isPremium && variation > 1) {
                var $previewContainer = $button.siblings('.weather-image-preview');
                setupLockedState($previewContainer);
                $button.prop('disabled', true).addClass('disabled');
            }
        });
    }, 500);

    function setupLockedState($container) {
        // Apply blur effect to the image container
        $container.find('img').css({
            'filter': 'blur(5px)',
            '-webkit-filter': 'blur(5px)',
            'transition': 'filter 0.3s ease'
        });
        
        // Add a clickable premium badge in the center
        if (!$container.find('.premium-badge').length) {
            $container.append('\
                <a href="https://buy.stripe.com/14kg2G9Gefrf4aQ001" target="_blank" class="premium-badge" style="position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); background-color: #228be6; color: white; padding: 5px 10px; border-radius: 4px; font-size: 14px; font-weight: bold; z-index: 10; text-decoration: none; cursor: pointer; box-shadow: 0 2px 4px rgba(0,0,0,0.2);">Premium Only</a>\
            ');
        }
    }

    // Always check variations and apply locked state for non-premium
    $('.weather-image-preview').each(function() {
        var variation = parseInt($(this).siblings('.weather-image-upload').data('variation'));
        if (variation > 1) {
            if (!isPremium) {
                setupLockedState($(this));
                $(this).siblings('.weather-image-upload').prop('disabled', true).addClass('disabled');
            }
        } else if ($(this).is(':empty')) {
            // Add placeholder for empty first variation
            $(this).html('<div class="weather-image-placeholder"><span class="dashicons dashicons-format-image"></span></div>');
        }
    });

    // Store the current frame and button
    var currentFrame = null;
    var currentButton = null;

    // Handle image upload button click
    $('.weather-image-upload').on('click', function(e) {
        e.preventDefault();
        console.log('Weather image upload button clicked');

        currentButton = $(this);
        var variation = parseInt(currentButton.data('variation'));
        var imageType = currentButton.data('type');
        var frameId = imageType + '_' + variation;

        console.log('Button data:', {
            variation: variation,
            imageType: imageType,
            frameId: frameId,
            isPremium: isPremium
        });

        // Only block variations 2 and 3 for non-premium users
        if (!isPremium && variation > 1) {
            var $previewContainer = currentButton.siblings('.weather-image-preview');
            
            // Apply blur effect to the image
            $previewContainer.find('img').css({
                'filter': 'blur(5px)',
                '-webkit-filter': 'blur(5px)',
                'transition': 'filter 0.3s ease'
            });
            
            // Add a clickable premium badge in the center if it doesn't exist
            if (!$previewContainer.find('.premium-badge').length) {
                $previewContainer.append('\
                    <a href="https://buy.stripe.com/14kg2G9Gefrf4aQ001" target="_blank" class="premium-badge" style="position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); background-color: #228be6; color: white; padding: 5px 10px; border-radius: 4px; font-size: 14px; font-weight: bold; z-index: 10; text-decoration: none; cursor: pointer; box-shadow: 0 2px 4px rgba(0,0,0,0.2);">Premium Only</a>\
                ');
            }
            
            currentButton.prop('disabled', true).addClass('disabled');
            alert('Premium account required to use additional image variations. Click the "Premium Only" button to upgrade and unlock all weather images!');
            return;
        }

        // Create a new frame each time to avoid issues with cached frames
        var frame = wp.media({
            title: 'Select Weather Image',
            button: {
                text: 'Use this image'
            },
            multiple: false,
            library: {
                type: 'image'
            }
        });

        // Set up select handler
        frame.on('select', function() {
            var attachment = frame.state().get('selection').first().toJSON();
            var previewContainer = currentButton.siblings('.weather-image-preview');
            
            console.log('Selected attachment:', attachment);



                // Save the image data via AJAX
                // Debug info
                console.log('Sending AJAX request with:', {
                    action: 'save_weather_image',
                    nonce: newspaperAIWeather.nonce,
                    type: imageType,
                    variation: variation,
                    image_id: attachment.id,
                    image_url: attachment.url
                });
                
                $.ajax({
                    url: newspaperAIWeather.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'save_weather_image',
                        nonce: newspaperAIWeather.nonce,
                        type: imageType,
                        variation: variation,
                        image_id: attachment.id,
                        image_url: attachment.url
                    },
                    success: function(response) {
                        console.log('AJAX response:', response);
                        if (response.success) {
                            // Always update preview regardless of premium status
                            previewContainer.html('<img src="' + attachment.url + '" alt="Weather image preview" />');
                            currentButton.text('Change Image');
                            
                            // Show success message
                            alert('Weather image updated successfully!');
                        } else {
                            console.error('Error response:', response);
                            // Show error message
                            var errorMessage = $('<div class="weather-write-error-message">'
                                    + '<p>' + (response.data || 'Error saving image') + '</p>'
                                    + '</div>');
                                previewContainer.html(errorMessage);
                                alert('Error saving image. Please try again.');
                            }
                        }
                    },
                    error: function(xhr, status, error) {
                        console.error('AJAX error:', status, error);
                        alert('Error saving image. Please try again. Error: ' + error);
                    }
                });
            });
        });

        // Open the media frame
        frame.open();
    });
});
