(function($) {
    'use strict';

    // Initialize all weather charts on the page
    function initWeatherCharts() {
        $('.weather-hourly-chart-container').each(function() {
            var $container = $(this);
            var chartId = $container.find('canvas').attr('id');
            var chartDataStr = $container.data('chart-data');
            
            if (chartId && chartDataStr) {
                try {
                    var chartData = (typeof chartDataStr === 'string') ? JSON.parse(chartDataStr) : chartDataStr;
                    initHourlyChart(chartId, chartData);
                } catch (e) {
                    console.error('Failed to parse chart data:', e);
                }
            }
        });
    }

    // Run initialization when document is ready
    $(document).ready(function() {
        initWeatherCharts();
    });



    // Function to initialize the hourly chart
    function initHourlyChart(chartId, data) {
        console.log('Initializing chart with ID:', chartId);
        console.log('Chart data:', data);
        
        const canvas = document.getElementById(chartId);
        if (!canvas) {
            console.error('Canvas element not found:', chartId);
            return;
        }

        const ctx = canvas.getContext('2d');
        if (!ctx) {
            console.error('Failed to get canvas context');
            return;
        }

        new Chart(ctx, {
            type: 'line',
            data: {
                labels: data.hours,
                datasets: [{
                    label: 'Temperature (°F)',
                    data: data.temperatures,
                    borderColor: 'rgb(255, 99, 132)',
                    backgroundColor: 'rgba(255, 99, 132, 0.2)',
                    tension: 0.4,
                    fill: true
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    tooltip: {
                        callbacks: {
                            afterLabel: function(context) {
                                const index = context.dataIndex;
                                return [
                                    'Conditions: ' + data.conditions[index],
                                    'Wind: ' + data.winds[index]
                                ];
                            }
                        }
                    }
                },
                scales: {
                    y: {
                        beginAtZero: false,
                        title: {
                            display: true,
                            text: 'Temperature (°F)'
                        }
                    }
                }
            }
        });
        console.log('Chart initialized successfully');
    }

    // Make the function globally available
    window.initWeatherHourlyChart = initHourlyChart;



    // Initialize hourly chart when data is available
    jQuery(document).ready(function($) {
        console.log('Weather script loaded');
        console.log('Weather hourly data:', weatherHourlyData);

        if (typeof weatherHourlyData !== 'undefined' && weatherHourlyData.chartId) {
            console.log('Chart ID:', weatherHourlyData.chartId);
            initHourlyChart(weatherHourlyData.chartId, weatherHourlyData);
        } else {
            console.log('No weather hourly data available');
        }
    });

})(jQuery);
