<?php
/**
 * Upgrade Banner for Weather Plugin
 * Adds a consistent upgrade banner to the settings page
 */

if (!defined('ABSPATH')) {
    exit;
}

// Add the banner to admin notices
add_action('admin_notices', 'weather_display_upgrade_banner');

/**
 * Display upgrade banner for non-premium users on the settings page
 */
function weather_display_upgrade_banner() {
    // Only show on our settings page
    $screen = get_current_screen();
    if (!$screen || strpos($screen->id, 'weatherai') === false) {
        return;
    }
    
    // Check premium status (same as scheduler page)
    $api_key = get_option('newspaperai_reintent_api_key');
    $api_error = get_option('reintent_api_error', '');
    $is_premium = !empty($api_key) && $api_error !== 'inactive_user';
    
    if (!$is_premium) {
        ?>
        <div class="upgrade-banner" style="background-color: #228be6; padding: 30px; margin: 20px 0; border-radius: 8px; color: white; display: flex; align-items: center; justify-content: space-between; font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif;">
            <div style="flex: 1;">
                <h1 style="color: white; margin: 0 0 15px 0; font-size: 24px;">Upgrade Today To Unlock Premium Features</h1>
                <p style="margin: 0; font-size: 16px; line-height: 1.6;">When you upgrade your weatherwrite account, you can access enhanced functionality, more customized images, scheduling options for up to 6 daily reports, and enhanced AI-generated weather reports tailored to your audience's needs.</p>
            </div>
            <div style="margin-left: 30px;">
                <a href="<?php echo esc_url(NewspaperAI_Reintent_API::UPGRADE_URL); ?>" target="_blank" class="button" style="background: white; color: #495057; border: none; padding: 12px 24px; font-weight: 600; text-decoration: none; display: inline-block; border-radius: 4px;">Upgrade Now</a>
            </div>
        </div>
        <?php
    }
}
