<?php
// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

$weather_images = NewspaperAI_Weather_Images::get_instance();

// Define weather conditions
$weather_conditions = array(
    'basic_sky' => array(
        'title' => 'Basic Sky Conditions',
        'conditions' => array(
            'sunny' => 'Sunny',
            'clear' => 'Clear Night',
            'partly_cloudy' => 'Partly Cloudy',
            'mostly_cloudy' => 'Mostly Cloudy',
            'overcast' => 'Overcast'
        )
    ),
    'rain' => array(
        'title' => 'Rain Variations',
        'conditions' => array(
            'rain_light' => 'Light Rain',
            'rain_heavy' => 'Heavy Rain',
            'showers' => 'Rain Showers'
        )
    ),
    'storm' => array(
        'title' => 'Storm Conditions',
        'conditions' => array(
            'thunderstorm' => 'Thunderstorm',
            'thunderstorm_severe' => 'Severe Thunderstorm'
        )
    ),
    'winter' => array(
        'title' => 'Winter Conditions',
        'conditions' => array(
            'snow_light' => 'Light Snow',
            'snow_heavy' => 'Heavy Snow',
            'sleet' => 'Sleet'
        )
    ),
    'special' => array(
        'title' => 'Special Conditions',
        'conditions' => array(
            'fog' => 'Fog',
            'mist' => 'Mist',
            'windy' => 'Windy',
            'hot' => 'Hot',
            'cold' => 'Cold'
        )
    ),
    'transitional' => array(
        'title' => 'Transitional Times',
        'conditions' => array(
            'sunrise' => 'Sunrise',
            'sunset' => 'Sunset'
        )
    )
);
?>

<div class="wrap">
    <h1>Weather Images</h1>
    
    <div class="notice notice-info">
        <p>Upload your custom weather images below. Each condition needs 3 different variations for variety.</p>
    </div>

    <div class="weather-images-container">
        <?php foreach ($weather_conditions as $category) : ?>
            <div class="weather-category">
                <h2><?php echo esc_html($category['title']); ?></h2>
                <div class="image-list">
                    <?php foreach ($category['conditions'] as $type => $label) : ?>
                        <div class="image-item">
                            <div class="image-name"><?php echo esc_html($label); ?></div>
                            <div class="image-variations">
                                <?php for ($i = 1; $i <= 3; $i++) : ?>
                                    <div class="image-variation">
                                        <div class="weather-image-preview">
                                            <?php $image_url = $weather_images->get_weather_image_url($type, $i); ?>
                                            <?php if ($image_url) : ?>
                                                <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr($label); ?> image <?php echo $i; ?>" />
                                            <?php endif; ?>
                                        </div>
                                        <button class="weather-image-upload" 
                                                data-type="<?php echo esc_attr($type); ?>" 
                                                data-variation="<?php echo esc_attr($i); ?>">
                                            <?php echo $image_url ? 'Change Image' : 'Upload Image'; ?>
                                        </button>
                                    </div>
                                <?php endfor; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endforeach; ?>
    </div>

    <div class="guidelines">
        <h3>Image Guidelines</h3>
        <ul>
            <li>Resolution: At least 1200x800 pixels for good quality</li>
            <li>Aspect ratio: 16:9 or 3:2 preferred for consistency</li>
            <li>Style: Natural, realistic weather conditions</li>
            <li>Focus: Weather should be the main subject</li>
            <li>Composition: Some sky visible in most shots</li>
            <li>Lighting: Natural lighting appropriate for the condition</li>
        </ul>
    </div>
</div>

<style>
.weather-images-container {
    margin: 20px 0;
}

.weather-category {
    background: #fff;
    border: 1px solid #ddd;
    border-radius: 5px;
    padding: 20px;
    margin-bottom: 20px;
}

.weather-category h2 {
    margin-top: 0;
    border-bottom: 2px solid #2271b1;
    padding-bottom: 10px;
}

.image-list {
    display: flex;
    flex-direction: column;
    gap: 20px;
}

.image-item {
    display: flex;
    align-items: center;
    padding: 15px;
    border: 1px solid #f0f0f0;
    border-radius: 4px;
}

.image-name {
    width: 150px;
    font-weight: 500;
}

.image-variations {
    display: flex;
    flex: 1;
    gap: 20px;
}

.image-variation {
    display: flex;
    flex-direction: column;
    align-items: center;
    gap: 10px;
}

.weather-image-preview {
    width: 150px;
    height: 100px;
    border: 1px solid #ddd;
    border-radius: 4px;
    overflow: hidden;
    background: #f0f0f0;
    display: flex;
    align-items: center;
    justify-content: center;
}

.weather-image-preview img {
    max-width: 100%;
    max-height: 100%;
    object-fit: cover;
}

.weather-image-upload {
    background: #2271b1;
    border: none;
    color: white;
    padding: 8px 12px;
    border-radius: 3px;
    cursor: pointer;
}

.weather-image-upload:hover {
    background: #135e96;
}

.guidelines {
    background: #f6f7f7;
    padding: 20px;
    border-left: 4px solid #2271b1;
    margin-top: 20px;
}
</style>
